use strict;

package ASCOPE::Article::Collection::NYTimes::CAN;
use base qw (Exporter);

# $Id: CAN.pm,v 1.3 2004/09/18 22:01:45 asc Exp $

=head1 NAME

ASCOPE::Article::Collection::NYTimes::CAN - Canada specific functions for ASCOPE::Article::Collection::NYTimes

=head1 SYNOPSIS

 Ceci n'est pas une boite noire. Please use
 ASCOPE::Article::Collection::NYTimes
    
=head1 DESCRIPTION

Canada specific functions for ASCOPE::Article::Collection::NYTimes

=cut

use vars qw (@EXPORT);
@EXPORT    = qw(cdnprovince_latlong
		cdnprovince_iso);

my $offset = undef;

sub cdnprovince_latlong {
    my $code = shift;

    $offset ||= tell DATA;
    seek(DATA,$offset,0);

    while (<DATA>) {
	my $ln = $_;

	if ($ln =~ /^(?:$code)/) {
	    
	    return (split(",",$ln))[2,3];
	}
    }
    
    return ();
}

sub cdnprovince_iso {
    my $prov = shift;

    my $iso = undef;

    $offset ||= tell DATA;
    seek(DATA,$offset,0);

    while (<DATA>) {
	my $ln = $_;

	if ($ln =~ /^([A-Z][A-Z]),$prov/) {
	    
	    $iso = $1;
	    last;
	}
    }
    
    return $iso;
}

=head1 VERSION

1.0

=head1 DATE

$Date: 2004/09/18 22:01:45 $

=head1 AUTHOR

Aaron Straup Cope E<lt>ascope@cpan.orgE<gt>

=head1 LICENSE

Copyright (c) 2004 Aaron Straup Cope. All rights reserved.

This is free software, you may use it and distribute it under
the same terms as Perl itself.

=cut

return 1;

__DATA__
AB,Alberta,55.0000,-115.0000
BC,British Columbia,55.0000,-125.0000
MB,Manitoba,55.0000,-97.0000
NB,New Brunswick,46.5000,-66.7500
NL,Newfoundland and Labrador,52.0000,-56.0000
NT,Northwest Territories,65.0000,-118.0000
NS,Nova Scotia,45.0000,-63.0000
NU,Nunavut,70.0000,-90.0000
ON,Ontario,50.0000,-86.0000
PE,Prince Edward Island,46.3333,-63.5000
PQ,Quebec,54.0000,-72.0000
QC,Quebec,54.0000,-72.0000
SK,Saskatchewan,54.0000,-106.0000
YT,Yukon Territory,64.0000,-165.0000
